@@ -366,8 +366,15 @@ class Model(object):
         for subtype_key in cls.__dict__.get('_subtype_map', {}).keys():
             subtype_value = None
 
-            rest_api_response_key = cls._get_rest_key_parts(subtype_key)[-1]
-            subtype_value = response.pop(rest_api_response_key, None) or response.pop(subtype_key, None)
+            if not isinstance(response, ET.Element):
+                rest_api_response_key = cls._get_rest_key_parts(subtype_key)[-1]
+                subtype_value = response.pop(rest_api_response_key, None) or response.pop(subtype_key, None)
+            else:
+                subtype_value = xml_key_extractor(
+                    subtype_key,
+                    cls._attribute_map[subtype_key],
+                    response
+                )
             if subtype_value:
                 # Try to match base class. Can be class name only
                 # (bug to fix in Autorest to support x-ms-discriminator-name)
